@@ -31,6 +31,15 @@ class ElasticDatabase(IDatabase):
     def delete(self):
         pass
 
+    def clear_data(self):
+        pass
+
+    def is_available(self):
+        try:
+            return self.get_session().ping()
+        except Exception:  # noqa E722
+            return False
+
     def get_base(self):
         return None
 
