@@ -1,5 +1,7 @@
 from typing import List, Callable
 
+from sqlalchemy.orm import scoped_session
+
 from petisco.persistence.interface_database import IDatabase
 from petisco.persistence.sql.mysql.mysql_connection import MySqlConnection
 from petisco.persistence.persistence_models import PersistenceModels
@@ -11,21 +13,29 @@ from petisco.persistence.sql.sql_session_scope_provider import (
 class MySqlDatabase(IDatabase):
     @staticmethod
     def local_connection_checker():
-        return MySqlDatabase(name="test", connection=MySqlConnection.create_local())
+        return MySqlDatabase(
+            name="test", connection=MySqlConnection.create_local("test")
+        )
 
     def __init__(
-        self, name: str, connection: MySqlConnection, model_filename: str = None
+        self,
+        name: str,
+        connection: MySqlConnection,
+        model_filename: str = None,
+        print_sql_statements: bool = False,
+        use_scoped_session: bool = True,
     ):
         if not connection or not isinstance(connection, MySqlConnection):
             raise ConnectionError(
                 "MySqlDatabase needs a valid MySqlConnection connection"
             )
-
         if model_filename:
             self.persistence_models = PersistenceModels.from_filename(model_filename)
         else:
             self.persistence_models = PersistenceModels(models={})
         self.connection = connection
+        self.print_sql_statements = print_sql_statements
+        self.use_scoped_session = use_scoped_session
 
         super().__init__(name, self.persistence_models.models)
         self._init()
@@ -46,6 +56,7 @@ class MySqlDatabase(IDatabase):
             pool_pre_ping=True,
             json_serializer=lambda obj: obj,
             json_deserializer=lambda obj: obj,
+            echo=self.print_sql_statements,
         )
 
         if not database_exists(engine.url):
@@ -89,7 +100,11 @@ class MySqlDatabase(IDatabase):
         return list(self.persistence_models.get_models_names().keys())
 
     def get_session(self):
-        return self.session_maker()
+        if self.use_scoped_session:
+            Session = scoped_session(self.session_maker)  # noqa
+        else:
+            Session = self.session_maker
+        return Session
 
     def get_session_scope(self) -> Callable:
         return sql_session_scope_provider(self.get_session())
