@@ -6,20 +6,32 @@ class WebhookRequestResult:
     def from_dict(kdict: dict):
         return WebhookRequestResult(
             headers=json.loads(kdict.get("headers")) if kdict.get("headers") else None,
-            body=kdict.get("body"),
+            body=json.loads(kdict.get("body")) if kdict.get("body") else None,
         )
 
     def to_dict(self):
         return {
             "headers": json.dumps(self.headers) if self.headers else None,
-            "body": self.body,
+            "body": json.dumps(self.body) if self.body else None,
         }
 
     def __init__(self, headers: dict, body: dict):
-        self.headers = headers
-        self.body = body
+        self._set_headers(headers)
+        self._set_body(body)
         super().__init__()
 
+    def _set_headers(self, headers):
+        try:
+            self.headers = dict(headers)
+        except Exception:
+            self.headers = {}
+
+    def _set_body(self, body):
+        try:
+            self.body = dict(body)
+        except Exception:
+            self.body = {}
+
     def __repr__(self):
         return json.dumps(self.to_dict())
 
